==> v0.13.11.tar.gz: git-next/crates/cli/src/alerts/webhook.rs <==
//
use git_next_core::{git::UserNotification, server::OutboundWebhook};
use kxio::network::{NetRequest, NetUrl, RequestBody, ResponseType};
use secrecy::ExposeSecret as _;
use standardwebhooks::Webhook;

pub(super) async fn send_webhook(
    user_notification: &UserNotification,
    webhook_config: &OutboundWebhook,
    net: &kxio::network::Network,
) {
    let Ok(webhook) =
        Webhook::from_bytes(webhook_config.secret().expose_secret().as_bytes().into())
    else {
        tracing::warn!("Invalid notification configuration (signer) - can't sent notification");
        return;
    };
    do_send_webhook(user_notification, webhook, webhook_config, net).await;
}

async fn do_send_webhook(
    user_notification: &UserNotification,
    webhook: Webhook,
    webhook_config: &OutboundWebhook,
    net: &kxio::network::Network,
) {
    let message_id = format!("msg_{}", ulid::Ulid::new());
    let timestamp = time::OffsetDateTime::now_utc();
    let payload = user_notification.as_json(timestamp);
    let timestamp = timestamp.unix_timestamp();
    let to_sign = format!("{message_id}.{timestamp}.{payload}");
    tracing::info!(?to_sign, "");
    #[allow(clippy::expect_used)]
    let signature = webhook
        .sign(&message_id, timestamp, payload.to_string().as_ref())
        .expect("signature");
    tracing::info!(?signature, "");
    let url = webhook_config.url();

    let net_url = NetUrl::new(url.to_string());
    let request = NetRequest::post(net_url)
        .body(RequestBody::Json(payload))
        .header("webhook-id", &message_id)
        .header("webhook-timestamp", &timestamp.to_string())
        .header("webhook-signature", &signature)
        .response_type(ResponseType::None)
        .build();
    net.post_json::<()>(request).await.map_or_else(
        |err| {
            tracing::warn!(?err, "sending webhook");
        },
        |_| (),
    );
}

==> v0.14.1.tar.gz: git-next/crates/cli/src/alerts/webhook.rs <==
//
use git_next_core::{git::UserNotification, server::OutboundWebhook};
use secrecy::ExposeSecret as _;
use standardwebhooks::Webhook;

pub(super) async fn send_webhook(
    user_notification: &UserNotification,
    webhook_config: &OutboundWebhook,
    net: &kxio::net::Net,
) {
    let Ok(webhook) =
        Webhook::from_bytes(webhook_config.secret().expose_secret().as_bytes().into())
    else {
        tracing::warn!("Invalid notification configuration (signer) - can't sent notification");
        return;
    };
    do_send_webhook(user_notification, webhook, webhook_config, net).await;
}

async fn do_send_webhook(
    user_notification: &UserNotification,
    webhook: Webhook,
    webhook_config: &OutboundWebhook,
    net: &kxio::net::Net,
) {
    let message_id = format!("msg_{}", ulid::Ulid::new());
    let timestamp = time::OffsetDateTime::now_utc();
    let payload = user_notification.as_json(timestamp);
    let timestamp = timestamp.unix_timestamp();
    let to_sign = format!("{message_id}.{timestamp}.{payload}");
    tracing::info!(?to_sign, "");
    #[allow(clippy::expect_used)]
    let signature = webhook
        .sign(&message_id, timestamp, payload.to_string().as_ref())
        .expect("signature");
    tracing::info!(?signature, "");
    net.post(webhook_config.url())
        .body(payload.to_string())
        .header("webhook-id", message_id)
        .header("webhook-timestamp", timestamp.to_string())
        .header("webhook-signature", signature)
        .send()
        .await
        .map_or_else(
            |err| {
                tracing::warn!(?err, "sending webhook");
            },
            |_| (),
        );
}
